@@ -111,6 +111,10 @@ pub struct CliArgs {
     #[clap(short = 'u', long = "upload-files")]
     pub file_upload: bool,
 
+    /// Enable creating directories
+    #[clap(short = 'U', long = "mkdir", requires = "file-upload")]
+    pub mkdir_enabled: bool,
+
     /// Specify uploadable media types
     #[clap(arg_enum, short = 'm', long = "media-type", requires = "file-upload")]
     pub media_type: Option<Vec<MediaType>>,
@@ -168,6 +172,10 @@ pub struct CliArgs {
     #[clap(short = 'F', long = "hide-version-footer")]
     pub hide_version_footer: bool,
 
+    /// Hide theme selector
+    #[clap(long = "hide-theme-selector")]
+    pub hide_theme_selector: bool,
+
     /// If enabled, display a wget command to recursively download the current directory
     #[clap(short = 'W', long = "show-wget-footer")]
     pub show_wget_footer: bool,
